import { Pool } from 'pg';
import { config } from '../config';
import { createUsersTable, getAllUsers, createUser } from './users.repository'; // 添加这行导入

// 创建连接池
const pool = new Pool({
  user: config.db.user,
  host: config.db.host,
  database: config.db.database,
  password: config.db.password,
  port: config.db.port,
});

// 导出查询函数
export const query = async (text: string, params?: any[]) => {
  try {
    return await pool.query(text, params);
  } catch (error) {
    const err = error as Error;
    throw new Error(`Database query failed: ${err.message}`);
  }
};

// 测试数据库连接
export const testDbConnection = async () => {
  try {
    const result = await query('SELECT NOW()');
    return { time: result.rows[0].now };
  } catch (error) {
    const err = error as Error;
    throw new Error(`Database connection failed: ${err.message}`);
  }
};

// 添加通用错误处理
pool.on('error', (err: Error) => {
  console.error('Unexpected database error', err);
});

// 导出所有需要的函数
export { createUsersTable, getAllUsers, createUser }; // 添加这行导出