import { Router } from 'express';
import { testDbConnection, createUsersTable } from '../database'; // 现在从 index 导入

const router = Router();

router.get('/health', async (req, res) => {
  try {
    const dbStatus = await testDbConnection();
    res.json({
      status: 'UP',
      database: dbStatus
    });
  } catch (error) {
    const err = error as Error;
    res.status(500).json({
      status: 'DOWN',
      error: err.message
    });
  }
});

router.get('/create-table', async (req, res) => {
  try {
    const result = await createUsersTable();
    res.json(result);
  } catch (error) {
    const err = error as Error;
    res.status(500).json({ error: err.message });
  }
});

export default router;