import { Router } from 'express';
import { getAllUsers, createUser } from '../database'; // 现在从 index 导入
import { User } from '../types/user.type';

const router = Router();

// 获取所有用户
router.get('/', async (req, res) => {
  try {
    const users = await getAllUsers();
    res.json(users);
  } catch (error) {
    const err = error as Error;
    res.status(500).json({ error: err.message });
  }
});

// 创建用户
router.post('/', async (req, res) => {
  try {
    const newUser: Omit<User, 'id'> = req.body;
    const createdUser = await createUser(newUser);
    res.status(201).json(createdUser);
  } catch (error) {
    const err = error as Error;
    res.status(400).json({ error: err.message });
  }
});

export default router;